import logging
import huggingface_hub.utils as hf_hub_utils
import pandas as pd
logging.disable(logging.INFO) # disable INFO 
logging.disable(logging.DEBUG) # disable INFO 
logging.disable(logging.WARNING) # disable INFO 
hf_hub_utils.disable_progress_bars()
pd.options.display.max_colwidth = None

