paths = { 
    "autocomplete": {"marathi-gpt": "l3cube-pune/marathi-gpt"},

    "hate": {"mahahate-bert": "l3cube-pune/mahahate-bert",
             "mahahate-multi-roberta": "l3cube-pune/mahahate-multi-roberta"},
    
    "maskFill": {"marathi-bert-v2": "l3cube-pune/marathi-bert-v2",
                 "marathi-roberta": "l3cube-pune/marathi-roberta",
                 "marathi-albert": "l3cube-pune/marathi-albert"},
    
    "sentiment": {"MarathiSentiment": "l3cube-pune/MarathiSentiment"},

    "similarity": {"marathi-sentence-similarity-sbert": "l3cube-pune/marathi-sentence-similarity-sbert",
                   "marathi-sentence-bert-nli": "l3cube-pune/marathi-sentence-bert-nli"},
   
    "tagger": {"marathi-ner": "l3cube-pune/marathi-ner"}
    
}
